@@ -60,9 +60,12 @@ class Stream:
                 .get_output_streams()
     return streams
 
-  def loop_back(self, operation):
-    Helper.check_loop_back(self, operation, self._app._nodes)
-    Helper.write_arc_to_file({"name" : self._name, "origin" : self._previous_node_name, "dest" : operation, "loop_back" : 1}, self._app._socket)
+  def loop_back(self, operation, max_iterations=None):
+    Helper.check_loop_back(self, operation, max_iterations, self._app._nodes)
+    arc_hash = {"name" : self._name, "origin" : self._previous_node_name, "dest" : operation, "loop_back" : 1}
+    if max_iterations != None:
+      arc_hash["max_iterations"] = max_iterations
+    Helper.write_arc_to_file(arc_hash, self._app._socket)
     return self
 
   def sink(self, name=None, columns=None, relation=None, scope=None):
